# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class FactWorkStarted(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'performer_id': 'str',
        'trip_id': 'str',
        'order_id': 'str',
        'demand_key': 'str',
        'fact_time': 'datetime'
    }

    attribute_map = {
        'performer_id': 'performer_id',
        'trip_id': 'trip_id',
        'order_id': 'order_id',
        'demand_key': 'demand_key',
        'fact_time': 'fact_time'
    }

    def __init__(self, performer_id=None, trip_id=None, order_id=None, demand_key=None, fact_time=None, local_vars_configuration=None):  # noqa: E501
        """FactWorkStarted - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._performer_id = None
        self._trip_id = None
        self._order_id = None
        self._demand_key = None
        self._fact_time = None
        self.discriminator = None

        self.performer_id = performer_id
        self.trip_id = trip_id
        self.order_id = order_id
        self.demand_key = demand_key
        if fact_time is not None:
            self.fact_time = fact_time

    @property
    def performer_id(self):
        """Gets the performer_id of this FactWorkStarted.  # noqa: E501

        Performer's ID.  # noqa: E501

        :return: The performer_id of this FactWorkStarted.  # noqa: E501
        :rtype: str
        """
        return self._performer_id

    @performer_id.setter
    def performer_id(self, performer_id):
        """Sets the performer_id of this FactWorkStarted.

        Performer's ID.  # noqa: E501

        :param performer_id: The performer_id of this FactWorkStarted.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and performer_id is None:  # noqa: E501
            raise ValueError("Invalid value for `performer_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                performer_id is not None and len(performer_id) > 1024):
            raise ValueError("Invalid value for `performer_id`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                performer_id is not None and len(performer_id) < 1):
            raise ValueError("Invalid value for `performer_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._performer_id = performer_id

    @property
    def trip_id(self):
        """Gets the trip_id of this FactWorkStarted.  # noqa: E501

        Trip ID.  # noqa: E501

        :return: The trip_id of this FactWorkStarted.  # noqa: E501
        :rtype: str
        """
        return self._trip_id

    @trip_id.setter
    def trip_id(self, trip_id):
        """Sets the trip_id of this FactWorkStarted.

        Trip ID.  # noqa: E501

        :param trip_id: The trip_id of this FactWorkStarted.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and trip_id is None:  # noqa: E501
            raise ValueError("Invalid value for `trip_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                trip_id is not None and len(trip_id) > 1024):
            raise ValueError("Invalid value for `trip_id`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                trip_id is not None and len(trip_id) < 1):
            raise ValueError("Invalid value for `trip_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._trip_id = trip_id

    @property
    def order_id(self):
        """Gets the order_id of this FactWorkStarted.  # noqa: E501

        Order ID.  # noqa: E501

        :return: The order_id of this FactWorkStarted.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this FactWorkStarted.

        Order ID.  # noqa: E501

        :param order_id: The order_id of this FactWorkStarted.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and order_id is None:  # noqa: E501
            raise ValueError("Invalid value for `order_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                order_id is not None and len(order_id) > 1024):
            raise ValueError("Invalid value for `order_id`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                order_id is not None and len(order_id) < 1):
            raise ValueError("Invalid value for `order_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._order_id = order_id

    @property
    def demand_key(self):
        """Gets the demand_key of this FactWorkStarted.  # noqa: E501

        Demand key.  # noqa: E501

        :return: The demand_key of this FactWorkStarted.  # noqa: E501
        :rtype: str
        """
        return self._demand_key

    @demand_key.setter
    def demand_key(self, demand_key):
        """Sets the demand_key of this FactWorkStarted.

        Demand key.  # noqa: E501

        :param demand_key: The demand_key of this FactWorkStarted.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and demand_key is None:  # noqa: E501
            raise ValueError("Invalid value for `demand_key`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                demand_key is not None and len(demand_key) > 1024):
            raise ValueError("Invalid value for `demand_key`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                demand_key is not None and len(demand_key) < 1):
            raise ValueError("Invalid value for `demand_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._demand_key = demand_key

    @property
    def fact_time(self):
        """Gets the fact_time of this FactWorkStarted.  # noqa: E501

        Fact time in the [RFC 3339, section 5.6](https://tools.ietf.org/html/rfc3339#section-5.6) format.  # noqa: E501

        :return: The fact_time of this FactWorkStarted.  # noqa: E501
        :rtype: datetime
        """
        return self._fact_time

    @fact_time.setter
    def fact_time(self, fact_time):
        """Sets the fact_time of this FactWorkStarted.

        Fact time in the [RFC 3339, section 5.6](https://tools.ietf.org/html/rfc3339#section-5.6) format.  # noqa: E501

        :param fact_time: The fact_time of this FactWorkStarted.  # noqa: E501
        :type: datetime
        """

        self._fact_time = fact_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FactWorkStarted):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FactWorkStarted):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class Capacity(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'mass': 'float',
        'volume': 'float',
        'capacity_x': 'float',
        'capacity_y': 'float',
        'capacity_z': 'float'
    }

    attribute_map = {
        'mass': 'mass',
        'volume': 'volume',
        'capacity_x': 'capacity_x',
        'capacity_y': 'capacity_y',
        'capacity_z': 'capacity_z'
    }

    def __init__(self, mass=1, volume=0, capacity_x=0, capacity_y=0, capacity_z=0, local_vars_configuration=None):  # noqa: E501
        """Capacity - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._mass = None
        self._volume = None
        self._capacity_x = None
        self._capacity_y = None
        self._capacity_z = None
        self.discriminator = None

        self.mass = mass
        if volume is not None:
            self.volume = volume
        if capacity_x is not None:
            self.capacity_x = capacity_x
        if capacity_y is not None:
            self.capacity_y = capacity_y
        if capacity_z is not None:
            self.capacity_z = capacity_z

    @property
    def mass(self):
        """Gets the mass of this Capacity.  # noqa: E501

        Weight in kilos.  # noqa: E501

        :return: The mass of this Capacity.  # noqa: E501
        :rtype: float
        """
        return self._mass

    @mass.setter
    def mass(self, mass):
        """Sets the mass of this Capacity.

        Weight in kilos.  # noqa: E501

        :param mass: The mass of this Capacity.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and mass is None:  # noqa: E501
            raise ValueError("Invalid value for `mass`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                mass is not None and mass < 0):  # noqa: E501
            raise ValueError("Invalid value for `mass`, must be a value greater than or equal to `0`")  # noqa: E501

        self._mass = mass

    @property
    def volume(self):
        """Gets the volume of this Capacity.  # noqa: E501

        Volume in cubic meters.  # noqa: E501

        :return: The volume of this Capacity.  # noqa: E501
        :rtype: float
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """Sets the volume of this Capacity.

        Volume in cubic meters.  # noqa: E501

        :param volume: The volume of this Capacity.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                volume is not None and volume < 0):  # noqa: E501
            raise ValueError("Invalid value for `volume`, must be a value greater than or equal to `0`")  # noqa: E501

        self._volume = volume

    @property
    def capacity_x(self):
        """Gets the capacity_x of this Capacity.  # noqa: E501

        Additional capacity parameter (X) for measurement of cargoes and compartments in alternative units. In example, to account for goods in units (this parameter equals 1 for a cargo, and the maximum number or placed cargoes - for a compartment).   # noqa: E501

        :return: The capacity_x of this Capacity.  # noqa: E501
        :rtype: float
        """
        return self._capacity_x

    @capacity_x.setter
    def capacity_x(self, capacity_x):
        """Sets the capacity_x of this Capacity.

        Additional capacity parameter (X) for measurement of cargoes and compartments in alternative units. In example, to account for goods in units (this parameter equals 1 for a cargo, and the maximum number or placed cargoes - for a compartment).   # noqa: E501

        :param capacity_x: The capacity_x of this Capacity.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                capacity_x is not None and capacity_x < 0):  # noqa: E501
            raise ValueError("Invalid value for `capacity_x`, must be a value greater than or equal to `0`")  # noqa: E501

        self._capacity_x = capacity_x

    @property
    def capacity_y(self):
        """Gets the capacity_y of this Capacity.  # noqa: E501

        Additional capacity parameter (Y) for measurement of cargoes and compartments in alternative units.  # noqa: E501

        :return: The capacity_y of this Capacity.  # noqa: E501
        :rtype: float
        """
        return self._capacity_y

    @capacity_y.setter
    def capacity_y(self, capacity_y):
        """Sets the capacity_y of this Capacity.

        Additional capacity parameter (Y) for measurement of cargoes and compartments in alternative units.  # noqa: E501

        :param capacity_y: The capacity_y of this Capacity.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                capacity_y is not None and capacity_y < 0):  # noqa: E501
            raise ValueError("Invalid value for `capacity_y`, must be a value greater than or equal to `0`")  # noqa: E501

        self._capacity_y = capacity_y

    @property
    def capacity_z(self):
        """Gets the capacity_z of this Capacity.  # noqa: E501

        Additional capacity parameter (X) for measurement of cargoes and compartments in alternative units.  # noqa: E501

        :return: The capacity_z of this Capacity.  # noqa: E501
        :rtype: float
        """
        return self._capacity_z

    @capacity_z.setter
    def capacity_z(self, capacity_z):
        """Sets the capacity_z of this Capacity.

        Additional capacity parameter (X) for measurement of cargoes and compartments in alternative units.  # noqa: E501

        :param capacity_z: The capacity_z of this Capacity.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                capacity_z is not None and capacity_z < 0):  # noqa: E501
            raise ValueError("Invalid value for `capacity_z`, must be a value greater than or equal to `0`")  # noqa: E501

        self._capacity_z = capacity_z

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Capacity):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Capacity):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class FactsResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'job_done': 'list[FactJobDone]',
        'demand_done': 'list[FactDemandDone]',
        'demand_cancellation': 'list[FactDemandCancellation]',
        'demand_payment': 'list[FactDemandPayment]',
        'demand_resumed': 'list[FactDemandResumed]',
        'event_window_changed': 'list[FactEventWindowChanged]',
        'performer_message': 'list[FactPerformerMessage]',
        'trip_status_notice': 'list[FactTripStatusNotice]',
        'tripaction_comment_changed': 'list[FactTripactionCommentChanged]',
        'work_started': 'list[FactWorkStarted]',
        'trip_progress': 'list[FactTripProgress]',
        'photo': 'list[FactPhoto]'
    }

    attribute_map = {
        'job_done': 'job_done',
        'demand_done': 'demand_done',
        'demand_cancellation': 'demand_cancellation',
        'demand_payment': 'demand_payment',
        'demand_resumed': 'demand_resumed',
        'event_window_changed': 'event_window_changed',
        'performer_message': 'performer_message',
        'trip_status_notice': 'trip_status_notice',
        'tripaction_comment_changed': 'tripaction_comment_changed',
        'work_started': 'work_started',
        'trip_progress': 'trip_progress',
        'photo': 'photo'
    }

    def __init__(self, job_done=None, demand_done=None, demand_cancellation=None, demand_payment=None, demand_resumed=None, event_window_changed=None, performer_message=None, trip_status_notice=None, tripaction_comment_changed=None, work_started=None, trip_progress=None, photo=None, local_vars_configuration=None):  # noqa: E501
        """FactsResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._job_done = None
        self._demand_done = None
        self._demand_cancellation = None
        self._demand_payment = None
        self._demand_resumed = None
        self._event_window_changed = None
        self._performer_message = None
        self._trip_status_notice = None
        self._tripaction_comment_changed = None
        self._work_started = None
        self._trip_progress = None
        self._photo = None
        self.discriminator = None

        if job_done is not None:
            self.job_done = job_done
        if demand_done is not None:
            self.demand_done = demand_done
        if demand_cancellation is not None:
            self.demand_cancellation = demand_cancellation
        if demand_payment is not None:
            self.demand_payment = demand_payment
        if demand_resumed is not None:
            self.demand_resumed = demand_resumed
        if event_window_changed is not None:
            self.event_window_changed = event_window_changed
        if performer_message is not None:
            self.performer_message = performer_message
        if trip_status_notice is not None:
            self.trip_status_notice = trip_status_notice
        if tripaction_comment_changed is not None:
            self.tripaction_comment_changed = tripaction_comment_changed
        if work_started is not None:
            self.work_started = work_started
        if trip_progress is not None:
            self.trip_progress = trip_progress
        if photo is not None:
            self.photo = photo

    @property
    def job_done(self):
        """Gets the job_done of this FactsResult.  # noqa: E501

        Facts list 'FactJobDone'.  # noqa: E501

        :return: The job_done of this FactsResult.  # noqa: E501
        :rtype: list[FactJobDone]
        """
        return self._job_done

    @job_done.setter
    def job_done(self, job_done):
        """Sets the job_done of this FactsResult.

        Facts list 'FactJobDone'.  # noqa: E501

        :param job_done: The job_done of this FactsResult.  # noqa: E501
        :type: list[FactJobDone]
        """

        self._job_done = job_done

    @property
    def demand_done(self):
        """Gets the demand_done of this FactsResult.  # noqa: E501

        Facts list 'FactDemandDone'.  # noqa: E501

        :return: The demand_done of this FactsResult.  # noqa: E501
        :rtype: list[FactDemandDone]
        """
        return self._demand_done

    @demand_done.setter
    def demand_done(self, demand_done):
        """Sets the demand_done of this FactsResult.

        Facts list 'FactDemandDone'.  # noqa: E501

        :param demand_done: The demand_done of this FactsResult.  # noqa: E501
        :type: list[FactDemandDone]
        """

        self._demand_done = demand_done

    @property
    def demand_cancellation(self):
        """Gets the demand_cancellation of this FactsResult.  # noqa: E501

        Facts list 'FactDemandCancellation'.  # noqa: E501

        :return: The demand_cancellation of this FactsResult.  # noqa: E501
        :rtype: list[FactDemandCancellation]
        """
        return self._demand_cancellation

    @demand_cancellation.setter
    def demand_cancellation(self, demand_cancellation):
        """Sets the demand_cancellation of this FactsResult.

        Facts list 'FactDemandCancellation'.  # noqa: E501

        :param demand_cancellation: The demand_cancellation of this FactsResult.  # noqa: E501
        :type: list[FactDemandCancellation]
        """

        self._demand_cancellation = demand_cancellation

    @property
    def demand_payment(self):
        """Gets the demand_payment of this FactsResult.  # noqa: E501

        Facts list 'FactDemandPayment'.  # noqa: E501

        :return: The demand_payment of this FactsResult.  # noqa: E501
        :rtype: list[FactDemandPayment]
        """
        return self._demand_payment

    @demand_payment.setter
    def demand_payment(self, demand_payment):
        """Sets the demand_payment of this FactsResult.

        Facts list 'FactDemandPayment'.  # noqa: E501

        :param demand_payment: The demand_payment of this FactsResult.  # noqa: E501
        :type: list[FactDemandPayment]
        """

        self._demand_payment = demand_payment

    @property
    def demand_resumed(self):
        """Gets the demand_resumed of this FactsResult.  # noqa: E501

        Facts list 'FactDemandResumed'.  # noqa: E501

        :return: The demand_resumed of this FactsResult.  # noqa: E501
        :rtype: list[FactDemandResumed]
        """
        return self._demand_resumed

    @demand_resumed.setter
    def demand_resumed(self, demand_resumed):
        """Sets the demand_resumed of this FactsResult.

        Facts list 'FactDemandResumed'.  # noqa: E501

        :param demand_resumed: The demand_resumed of this FactsResult.  # noqa: E501
        :type: list[FactDemandResumed]
        """

        self._demand_resumed = demand_resumed

    @property
    def event_window_changed(self):
        """Gets the event_window_changed of this FactsResult.  # noqa: E501

        Facts list 'FactEventWindowChanged'.  # noqa: E501

        :return: The event_window_changed of this FactsResult.  # noqa: E501
        :rtype: list[FactEventWindowChanged]
        """
        return self._event_window_changed

    @event_window_changed.setter
    def event_window_changed(self, event_window_changed):
        """Sets the event_window_changed of this FactsResult.

        Facts list 'FactEventWindowChanged'.  # noqa: E501

        :param event_window_changed: The event_window_changed of this FactsResult.  # noqa: E501
        :type: list[FactEventWindowChanged]
        """

        self._event_window_changed = event_window_changed

    @property
    def performer_message(self):
        """Gets the performer_message of this FactsResult.  # noqa: E501

        Facts list 'FactPerformerMessage'.  # noqa: E501

        :return: The performer_message of this FactsResult.  # noqa: E501
        :rtype: list[FactPerformerMessage]
        """
        return self._performer_message

    @performer_message.setter
    def performer_message(self, performer_message):
        """Sets the performer_message of this FactsResult.

        Facts list 'FactPerformerMessage'.  # noqa: E501

        :param performer_message: The performer_message of this FactsResult.  # noqa: E501
        :type: list[FactPerformerMessage]
        """

        self._performer_message = performer_message

    @property
    def trip_status_notice(self):
        """Gets the trip_status_notice of this FactsResult.  # noqa: E501

        Facts list 'FactTripStatusNotice'.  # noqa: E501

        :return: The trip_status_notice of this FactsResult.  # noqa: E501
        :rtype: list[FactTripStatusNotice]
        """
        return self._trip_status_notice

    @trip_status_notice.setter
    def trip_status_notice(self, trip_status_notice):
        """Sets the trip_status_notice of this FactsResult.

        Facts list 'FactTripStatusNotice'.  # noqa: E501

        :param trip_status_notice: The trip_status_notice of this FactsResult.  # noqa: E501
        :type: list[FactTripStatusNotice]
        """

        self._trip_status_notice = trip_status_notice

    @property
    def tripaction_comment_changed(self):
        """Gets the tripaction_comment_changed of this FactsResult.  # noqa: E501

        Facts list 'FactTripactionCommentChanged'.  # noqa: E501

        :return: The tripaction_comment_changed of this FactsResult.  # noqa: E501
        :rtype: list[FactTripactionCommentChanged]
        """
        return self._tripaction_comment_changed

    @tripaction_comment_changed.setter
    def tripaction_comment_changed(self, tripaction_comment_changed):
        """Sets the tripaction_comment_changed of this FactsResult.

        Facts list 'FactTripactionCommentChanged'.  # noqa: E501

        :param tripaction_comment_changed: The tripaction_comment_changed of this FactsResult.  # noqa: E501
        :type: list[FactTripactionCommentChanged]
        """

        self._tripaction_comment_changed = tripaction_comment_changed

    @property
    def work_started(self):
        """Gets the work_started of this FactsResult.  # noqa: E501

        Facts list 'FactWorkStarted'.  # noqa: E501

        :return: The work_started of this FactsResult.  # noqa: E501
        :rtype: list[FactWorkStarted]
        """
        return self._work_started

    @work_started.setter
    def work_started(self, work_started):
        """Sets the work_started of this FactsResult.

        Facts list 'FactWorkStarted'.  # noqa: E501

        :param work_started: The work_started of this FactsResult.  # noqa: E501
        :type: list[FactWorkStarted]
        """

        self._work_started = work_started

    @property
    def trip_progress(self):
        """Gets the trip_progress of this FactsResult.  # noqa: E501

        Facts list 'FactTripProgress'.  # noqa: E501

        :return: The trip_progress of this FactsResult.  # noqa: E501
        :rtype: list[FactTripProgress]
        """
        return self._trip_progress

    @trip_progress.setter
    def trip_progress(self, trip_progress):
        """Sets the trip_progress of this FactsResult.

        Facts list 'FactTripProgress'.  # noqa: E501

        :param trip_progress: The trip_progress of this FactsResult.  # noqa: E501
        :type: list[FactTripProgress]
        """

        self._trip_progress = trip_progress

    @property
    def photo(self):
        """Gets the photo of this FactsResult.  # noqa: E501

        Facts list 'FactPhoto'.  # noqa: E501

        :return: The photo of this FactsResult.  # noqa: E501
        :rtype: list[FactPhoto]
        """
        return self._photo

    @photo.setter
    def photo(self, photo):
        """Sets the photo of this FactsResult.

        Facts list 'FactPhoto'.  # noqa: E501

        :param photo: The photo of this FactsResult.  # noqa: E501
        :type: list[FactPhoto]
        """

        self._photo = photo

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FactsResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FactsResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class FactPerformerMessage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'performer_id': 'str',
        'trip_id': 'str',
        'transport_id': 'str',
        'message_topic': 'str',
        'message': 'str',
        'storage_server_file_ids': 'list[str]',
        'fact_time': 'datetime'
    }

    attribute_map = {
        'performer_id': 'performer_id',
        'trip_id': 'trip_id',
        'transport_id': 'transport_id',
        'message_topic': 'message_topic',
        'message': 'message',
        'storage_server_file_ids': 'storage_server_file_ids',
        'fact_time': 'fact_time'
    }

    def __init__(self, performer_id=None, trip_id=None, transport_id=None, message_topic=None, message=None, storage_server_file_ids=None, fact_time=None, local_vars_configuration=None):  # noqa: E501
        """FactPerformerMessage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._performer_id = None
        self._trip_id = None
        self._transport_id = None
        self._message_topic = None
        self._message = None
        self._storage_server_file_ids = None
        self._fact_time = None
        self.discriminator = None

        self.performer_id = performer_id
        self.trip_id = trip_id
        self.transport_id = transport_id
        self.message_topic = message_topic
        if message is not None:
            self.message = message
        self.storage_server_file_ids = storage_server_file_ids
        if fact_time is not None:
            self.fact_time = fact_time

    @property
    def performer_id(self):
        """Gets the performer_id of this FactPerformerMessage.  # noqa: E501

        Performer's ID.  # noqa: E501

        :return: The performer_id of this FactPerformerMessage.  # noqa: E501
        :rtype: str
        """
        return self._performer_id

    @performer_id.setter
    def performer_id(self, performer_id):
        """Sets the performer_id of this FactPerformerMessage.

        Performer's ID.  # noqa: E501

        :param performer_id: The performer_id of this FactPerformerMessage.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and performer_id is None:  # noqa: E501
            raise ValueError("Invalid value for `performer_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                performer_id is not None and len(performer_id) > 1024):
            raise ValueError("Invalid value for `performer_id`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                performer_id is not None and len(performer_id) < 1):
            raise ValueError("Invalid value for `performer_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._performer_id = performer_id

    @property
    def trip_id(self):
        """Gets the trip_id of this FactPerformerMessage.  # noqa: E501

        Trip ID.  # noqa: E501

        :return: The trip_id of this FactPerformerMessage.  # noqa: E501
        :rtype: str
        """
        return self._trip_id

    @trip_id.setter
    def trip_id(self, trip_id):
        """Sets the trip_id of this FactPerformerMessage.

        Trip ID.  # noqa: E501

        :param trip_id: The trip_id of this FactPerformerMessage.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and trip_id is None:  # noqa: E501
            raise ValueError("Invalid value for `trip_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                trip_id is not None and len(trip_id) > 1024):
            raise ValueError("Invalid value for `trip_id`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                trip_id is not None and len(trip_id) < 1):
            raise ValueError("Invalid value for `trip_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._trip_id = trip_id

    @property
    def transport_id(self):
        """Gets the transport_id of this FactPerformerMessage.  # noqa: E501

        Vehicle ID.  # noqa: E501

        :return: The transport_id of this FactPerformerMessage.  # noqa: E501
        :rtype: str
        """
        return self._transport_id

    @transport_id.setter
    def transport_id(self, transport_id):
        """Sets the transport_id of this FactPerformerMessage.

        Vehicle ID.  # noqa: E501

        :param transport_id: The transport_id of this FactPerformerMessage.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and transport_id is None:  # noqa: E501
            raise ValueError("Invalid value for `transport_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                transport_id is not None and len(transport_id) > 1024):
            raise ValueError("Invalid value for `transport_id`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                transport_id is not None and len(transport_id) < 1):
            raise ValueError("Invalid value for `transport_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._transport_id = transport_id

    @property
    def message_topic(self):
        """Gets the message_topic of this FactPerformerMessage.  # noqa: E501

        Message topic.  # noqa: E501

        :return: The message_topic of this FactPerformerMessage.  # noqa: E501
        :rtype: str
        """
        return self._message_topic

    @message_topic.setter
    def message_topic(self, message_topic):
        """Sets the message_topic of this FactPerformerMessage.

        Message topic.  # noqa: E501

        :param message_topic: The message_topic of this FactPerformerMessage.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and message_topic is None:  # noqa: E501
            raise ValueError("Invalid value for `message_topic`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                message_topic is not None and len(message_topic) > 1000):
            raise ValueError("Invalid value for `message_topic`, length must be less than or equal to `1000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                message_topic is not None and len(message_topic) < 1):
            raise ValueError("Invalid value for `message_topic`, length must be greater than or equal to `1`")  # noqa: E501

        self._message_topic = message_topic

    @property
    def message(self):
        """Gets the message of this FactPerformerMessage.  # noqa: E501

        Message text.  # noqa: E501

        :return: The message of this FactPerformerMessage.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this FactPerformerMessage.

        Message text.  # noqa: E501

        :param message: The message of this FactPerformerMessage.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                message is not None and len(message) > 10000):
            raise ValueError("Invalid value for `message`, length must be less than or equal to `10000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                message is not None and len(message) < 1):
            raise ValueError("Invalid value for `message`, length must be greater than or equal to `1`")  # noqa: E501

        self._message = message

    @property
    def storage_server_file_ids(self):
        """Gets the storage_server_file_ids of this FactPerformerMessage.  # noqa: E501

        Attached files IDs.  # noqa: E501

        :return: The storage_server_file_ids of this FactPerformerMessage.  # noqa: E501
        :rtype: list[str]
        """
        return self._storage_server_file_ids

    @storage_server_file_ids.setter
    def storage_server_file_ids(self, storage_server_file_ids):
        """Sets the storage_server_file_ids of this FactPerformerMessage.

        Attached files IDs.  # noqa: E501

        :param storage_server_file_ids: The storage_server_file_ids of this FactPerformerMessage.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and storage_server_file_ids is None:  # noqa: E501
            raise ValueError("Invalid value for `storage_server_file_ids`, must not be `None`")  # noqa: E501

        self._storage_server_file_ids = storage_server_file_ids

    @property
    def fact_time(self):
        """Gets the fact_time of this FactPerformerMessage.  # noqa: E501

        Fact time in the [RFC 3339, section 5.6](https://tools.ietf.org/html/rfc3339#section-5.6) format.  # noqa: E501

        :return: The fact_time of this FactPerformerMessage.  # noqa: E501
        :rtype: datetime
        """
        return self._fact_time

    @fact_time.setter
    def fact_time(self, fact_time):
        """Sets the fact_time of this FactPerformerMessage.

        Fact time in the [RFC 3339, section 5.6](https://tools.ietf.org/html/rfc3339#section-5.6) format.  # noqa: E501

        :param fact_time: The fact_time of this FactPerformerMessage.  # noqa: E501
        :type: datetime
        """

        self._fact_time = fact_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FactPerformerMessage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FactPerformerMessage):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.capacity import Capacity  # noqa: E501
from vrt_ud.rest import ApiException

class TestCapacity(unittest.TestCase):
    """Capacity unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Capacity
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.capacity.Capacity()  # noqa: E501
        if include_optional :
            return Capacity(
                mass = 10, 
                volume = 2, 
                capacity_x = 1, 
                capacity_y = 2, 
                capacity_z = 3
            )
        else :
            return Capacity(
                mass = 10,
        )

    def testCapacity(self):
        """Test Capacity"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.fact_demand_done import FactDemandDone  # noqa: E501
from vrt_ud.rest import ApiException

class TestFactDemandDone(unittest.TestCase):
    """FactDemandDone unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test FactDemandDone
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.fact_demand_done.FactDemandDone()  # noqa: E501
        if include_optional :
            return FactDemandDone(
                performer_id = 'f_887', 
                trip_id = 'default', 
                order_id = 'default', 
                demand_key = 'default', 
                merchandise_lines = [
                    vrt_ud.models.merchandise_line.MerchandiseLine(
                        goods_name = 'boxes', 
                        goods_unit_name = 'box', 
                        goods_unit_price = 500, 
                        goods_amount = 2, 
                        goods_value = 1000, 
                        vat_rate = 'VAT0000', 
                        barcode = 'default', 
                        fact_time = '2020-10-21T09:30+03:00', )
                    ], 
                cancellations = [
                    vrt_ud.models.order_cancellation.OrderCancellation(
                        goods_name = 'boxes', 
                        goods_amount = 2, 
                        cancellation_reason = 'no reason', 
                        fact_time = '2020-10-21T09:30+03:00', )
                    ], 
                fact_time = '2020-10-21T09:30+03:00'
            )
        else :
            return FactDemandDone(
                performer_id = 'f_887',
                trip_id = 'default',
                order_id = 'default',
                demand_key = 'default',
        )

    def testFactDemandDone(self):
        """Test FactDemandDone"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class TripAction(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'order_key': 'str',
        'demand_key': 'str',
        'location_key': 'str',
        'todolist': 'list[TripJob]',
        'cargo_placements': 'list[CargoPlacement]'
    }

    attribute_map = {
        'order_key': 'order_key',
        'demand_key': 'demand_key',
        'location_key': 'location_key',
        'todolist': 'todolist',
        'cargo_placements': 'cargo_placements'
    }

    def __init__(self, order_key=None, demand_key=None, location_key=None, todolist=None, cargo_placements=None, local_vars_configuration=None):  # noqa: E501
        """TripAction - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._order_key = None
        self._demand_key = None
        self._location_key = None
        self._todolist = None
        self._cargo_placements = None
        self.discriminator = None

        self.order_key = order_key
        self.demand_key = demand_key
        self.location_key = location_key
        self.todolist = todolist
        if cargo_placements is not None:
            self.cargo_placements = cargo_placements

    @property
    def order_key(self):
        """Gets the order_key of this TripAction.  # noqa: E501

        Key of the order with which an action is taken.  # noqa: E501

        :return: The order_key of this TripAction.  # noqa: E501
        :rtype: str
        """
        return self._order_key

    @order_key.setter
    def order_key(self, order_key):
        """Sets the order_key of this TripAction.

        Key of the order with which an action is taken.  # noqa: E501

        :param order_key: The order_key of this TripAction.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and order_key is None:  # noqa: E501
            raise ValueError("Invalid value for `order_key`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                order_key is not None and len(order_key) > 1024):
            raise ValueError("Invalid value for `order_key`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                order_key is not None and len(order_key) < 1):
            raise ValueError("Invalid value for `order_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._order_key = order_key

    @property
    def demand_key(self):
        """Gets the demand_key of this TripAction.  # noqa: E501

        Key of the demand with which an action is taken.  # noqa: E501

        :return: The demand_key of this TripAction.  # noqa: E501
        :rtype: str
        """
        return self._demand_key

    @demand_key.setter
    def demand_key(self, demand_key):
        """Sets the demand_key of this TripAction.

        Key of the demand with which an action is taken.  # noqa: E501

        :param demand_key: The demand_key of this TripAction.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and demand_key is None:  # noqa: E501
            raise ValueError("Invalid value for `demand_key`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                demand_key is not None and len(demand_key) > 1024):
            raise ValueError("Invalid value for `demand_key`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                demand_key is not None and len(demand_key) < 1):
            raise ValueError("Invalid value for `demand_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._demand_key = demand_key

    @property
    def location_key(self):
        """Gets the location_key of this TripAction.  # noqa: E501

        Key of the location at which an action is taken.  # noqa: E501

        :return: The location_key of this TripAction.  # noqa: E501
        :rtype: str
        """
        return self._location_key

    @location_key.setter
    def location_key(self, location_key):
        """Sets the location_key of this TripAction.

        Key of the location at which an action is taken.  # noqa: E501

        :param location_key: The location_key of this TripAction.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and location_key is None:  # noqa: E501
            raise ValueError("Invalid value for `location_key`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                location_key is not None and len(location_key) > 1024):
            raise ValueError("Invalid value for `location_key`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                location_key is not None and len(location_key) < 1):
            raise ValueError("Invalid value for `location_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._location_key = location_key

    @property
    def todolist(self):
        """Gets the todolist of this TripAction.  # noqa: E501

        Works list, each is performed inside the 'job_time' time window.  # noqa: E501

        :return: The todolist of this TripAction.  # noqa: E501
        :rtype: list[TripJob]
        """
        return self._todolist

    @todolist.setter
    def todolist(self, todolist):
        """Sets the todolist of this TripAction.

        Works list, each is performed inside the 'job_time' time window.  # noqa: E501

        :param todolist: The todolist of this TripAction.  # noqa: E501
        :type: list[TripJob]
        """
        if self.local_vars_configuration.client_side_validation and todolist is None:  # noqa: E501
            raise ValueError("Invalid value for `todolist`, must not be `None`")  # noqa: E501

        self._todolist = todolist

    @property
    def cargo_placements(self):
        """Gets the cargo_placements of this TripAction.  # noqa: E501

        Cargo placements list.  # noqa: E501

        :return: The cargo_placements of this TripAction.  # noqa: E501
        :rtype: list[CargoPlacement]
        """
        return self._cargo_placements

    @cargo_placements.setter
    def cargo_placements(self, cargo_placements):
        """Sets the cargo_placements of this TripAction.

        Cargo placements list.  # noqa: E501

        :param cargo_placements: The cargo_placements of this TripAction.  # noqa: E501
        :type: list[CargoPlacement]
        """

        self._cargo_placements = cargo_placements

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TripAction):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TripAction):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.fact_tripaction_comment_changed import FactTripactionCommentChanged  # noqa: E501
from vrt_ud.rest import ApiException

class TestFactTripactionCommentChanged(unittest.TestCase):
    """FactTripactionCommentChanged unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test FactTripactionCommentChanged
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.fact_tripaction_comment_changed.FactTripactionCommentChanged()  # noqa: E501
        if include_optional :
            return FactTripactionCommentChanged(
                performer_id = 'f_887', 
                trip_id = 'default', 
                order_id = 'default', 
                demand_key = 'default', 
                old_comment_value = 'default', 
                new_comment_value = 'default', 
                fact_time = '2020-10-21T09:30+03:00'
            )
        else :
            return FactTripactionCommentChanged(
                performer_id = 'f_887',
                trip_id = 'default',
                order_id = 'default',
                demand_key = 'default',
                old_comment_value = 'default',
                new_comment_value = 'default',
        )

    def testFactTripactionCommentChanged(self):
        """Test FactTripactionCommentChanged"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.trip import Trip  # noqa: E501
from vrt_ud.rest import ApiException

class TestTrip(unittest.TestCase):
    """Trip unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Trip
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.trip.Trip()  # noqa: E501
        if include_optional :
            return Trip(
                key = 'TRIP0001', 
                trip_id = 'e42c94eb-4628-4131-9180-c931dfa50ed1', 
                assigned_shifts = [
                    vrt_ud.models.assigned_shift.AssignedShift(
                        shift_key = 'performer01', 
                        shift_time = vrt_ud.models.time_window.TimeWindow(
                            from = '2020-10-21T09:30+03:00', 
                            to = '2020-10-21T19:45Z', ), )
                    ], 
                actions = [
                    vrt_ud.models.trip_action.TripAction(
                        order_key = 'order01', 
                        demand_key = 'demand01.1', 
                        location_key = 'location01', 
                        todolist = [
                            vrt_ud.models.trip_job.TripJob(
                                job_type = 'START_WORK', 
                                job_time = '2020-10-21T09:30+03:00', )
                            ], 
                        cargo_placements = [
                            vrt_ud.models.cargo_placement.CargoPlacement(
                                box_key = 'box01', 
                                cargo_key = 'cargo01', )
                            ], )
                    ], 
                waitlist = ["order02"]
            )
        else :
            return Trip(
                key = 'TRIP0001',
                assigned_shifts = [
                    vrt_ud.models.assigned_shift.AssignedShift(
                        shift_key = 'performer01', 
                        shift_time = vrt_ud.models.time_window.TimeWindow(
                            from = '2020-10-21T09:30+03:00', 
                            to = '2020-10-21T19:45Z', ), )
                    ],
        )

    def testTrip(self):
        """Test Trip"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.trip_action import TripAction  # noqa: E501
from vrt_ud.rest import ApiException

class TestTripAction(unittest.TestCase):
    """TripAction unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TripAction
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.trip_action.TripAction()  # noqa: E501
        if include_optional :
            return TripAction(
                order_key = 'order01', 
                demand_key = 'demand01.1', 
                location_key = 'location01', 
                todolist = [
                    vrt_ud.models.trip_job.TripJob(
                        job_type = 'START_WORK', 
                        job_time = '2020-10-21T09:30+03:00', )
                    ], 
                cargo_placements = [
                    vrt_ud.models.cargo_placement.CargoPlacement(
                        box_key = 'box01', 
                        cargo_key = 'cargo01', )
                    ]
            )
        else :
            return TripAction(
                order_key = 'order01',
                demand_key = 'demand01.1',
                location_key = 'location01',
                todolist = [
                    vrt_ud.models.trip_job.TripJob(
                        job_type = 'START_WORK', 
                        job_time = '2020-10-21T09:30+03:00', )
                    ],
        )

    def testTripAction(self):
        """Test TripAction"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class PerformerTrack(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'shift_key': 'str',
        'points': 'list[TrackPoint]',
        'last_point': 'TrackPoint'
    }

    attribute_map = {
        'shift_key': 'shift_key',
        'points': 'points',
        'last_point': 'last_point'
    }

    def __init__(self, shift_key=None, points=None, last_point=None, local_vars_configuration=None):  # noqa: E501
        """PerformerTrack - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._shift_key = None
        self._points = None
        self._last_point = None
        self.discriminator = None

        self.shift_key = shift_key
        if points is not None:
            self.points = points
        self.last_point = last_point

    @property
    def shift_key(self):
        """Gets the shift_key of this PerformerTrack.  # noqa: E501

        Shift key.  # noqa: E501

        :return: The shift_key of this PerformerTrack.  # noqa: E501
        :rtype: str
        """
        return self._shift_key

    @shift_key.setter
    def shift_key(self, shift_key):
        """Sets the shift_key of this PerformerTrack.

        Shift key.  # noqa: E501

        :param shift_key: The shift_key of this PerformerTrack.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and shift_key is None:  # noqa: E501
            raise ValueError("Invalid value for `shift_key`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                shift_key is not None and len(shift_key) > 256):
            raise ValueError("Invalid value for `shift_key`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                shift_key is not None and len(shift_key) < 1):
            raise ValueError("Invalid value for `shift_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._shift_key = shift_key

    @property
    def points(self):
        """Gets the points of this PerformerTrack.  # noqa: E501

        Track points list.  # noqa: E501

        :return: The points of this PerformerTrack.  # noqa: E501
        :rtype: list[TrackPoint]
        """
        return self._points

    @points.setter
    def points(self, points):
        """Sets the points of this PerformerTrack.

        Track points list.  # noqa: E501

        :param points: The points of this PerformerTrack.  # noqa: E501
        :type: list[TrackPoint]
        """

        self._points = points

    @property
    def last_point(self):
        """Gets the last_point of this PerformerTrack.  # noqa: E501


        :return: The last_point of this PerformerTrack.  # noqa: E501
        :rtype: TrackPoint
        """
        return self._last_point

    @last_point.setter
    def last_point(self, last_point):
        """Sets the last_point of this PerformerTrack.


        :param last_point: The last_point of this PerformerTrack.  # noqa: E501
        :type: TrackPoint
        """

        self._last_point = last_point

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PerformerTrack):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PerformerTrack):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class PossibleEvent(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'location_key': 'str',
        'duration': 'int',
        'reward': 'float',
        'time_window': 'TimeWindow'
    }

    attribute_map = {
        'location_key': 'location_key',
        'duration': 'duration',
        'reward': 'reward',
        'time_window': 'time_window'
    }

    def __init__(self, location_key=None, duration=5, reward=None, time_window=None, local_vars_configuration=None):  # noqa: E501
        """PossibleEvent - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._location_key = None
        self._duration = None
        self._reward = None
        self._time_window = None
        self.discriminator = None

        self.location_key = location_key
        self.duration = duration
        self.reward = reward
        self.time_window = time_window

    @property
    def location_key(self):
        """Gets the location_key of this PossibleEvent.  # noqa: E501

        Key of the location, where the event is possible.  # noqa: E501

        :return: The location_key of this PossibleEvent.  # noqa: E501
        :rtype: str
        """
        return self._location_key

    @location_key.setter
    def location_key(self, location_key):
        """Sets the location_key of this PossibleEvent.

        Key of the location, where the event is possible.  # noqa: E501

        :param location_key: The location_key of this PossibleEvent.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and location_key is None:  # noqa: E501
            raise ValueError("Invalid value for `location_key`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                location_key is not None and len(location_key) > 1024):
            raise ValueError("Invalid value for `location_key`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                location_key is not None and len(location_key) < 1):
            raise ValueError("Invalid value for `location_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._location_key = location_key

    @property
    def duration(self):
        """Gets the duration of this PossibleEvent.  # noqa: E501

        Duration of demand completion in minutes.  # noqa: E501

        :return: The duration of this PossibleEvent.  # noqa: E501
        :rtype: int
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this PossibleEvent.

        Duration of demand completion in minutes.  # noqa: E501

        :param duration: The duration of this PossibleEvent.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and duration is None:  # noqa: E501
            raise ValueError("Invalid value for `duration`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                duration is not None and duration < 0):  # noqa: E501
            raise ValueError("Invalid value for `duration`, must be a value greater than or equal to `0`")  # noqa: E501

        self._duration = duration

    @property
    def reward(self):
        """Gets the reward of this PossibleEvent.  # noqa: E501

        Order fulfillment reward.  # noqa: E501

        :return: The reward of this PossibleEvent.  # noqa: E501
        :rtype: float
        """
        return self._reward

    @reward.setter
    def reward(self, reward):
        """Sets the reward of this PossibleEvent.

        Order fulfillment reward.  # noqa: E501

        :param reward: The reward of this PossibleEvent.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and reward is None:  # noqa: E501
            raise ValueError("Invalid value for `reward`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                reward is not None and reward < 0):  # noqa: E501
            raise ValueError("Invalid value for `reward`, must be a value greater than or equal to `0`")  # noqa: E501

        self._reward = reward

    @property
    def time_window(self):
        """Gets the time_window of this PossibleEvent.  # noqa: E501


        :return: The time_window of this PossibleEvent.  # noqa: E501
        :rtype: TimeWindow
        """
        return self._time_window

    @time_window.setter
    def time_window(self, time_window):
        """Sets the time_window of this PossibleEvent.


        :param time_window: The time_window of this PossibleEvent.  # noqa: E501
        :type: TimeWindow
        """
        if self.local_vars_configuration.client_side_validation and time_window is None:  # noqa: E501
            raise ValueError("Invalid value for `time_window`, must not be `None`")  # noqa: E501

        self._time_window = time_window

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PossibleEvent):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PossibleEvent):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.fact_demand_payment import FactDemandPayment  # noqa: E501
from vrt_ud.rest import ApiException

class TestFactDemandPayment(unittest.TestCase):
    """FactDemandPayment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test FactDemandPayment
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.fact_demand_payment.FactDemandPayment()  # noqa: E501
        if include_optional :
            return FactDemandPayment(
                performer_id = 'f_887', 
                trip_id = 'default', 
                order_id = 'default', 
                demand_key = 'default', 
                payment_details = vrt_ud.models.payment_details.PaymentDetails(
                    bill_number_in_shift = '1', 
                    bill_date_time = 'default', 
                    customer_email = 'customer@company.com', 
                    bill_amount_total = 1000, 
                    fd_number = 'default', 
                    fn_number = 'default', 
                    qr_code = 'default', 
                    payment_type = 'default', 
                    approval_code = 'default', 
                    kkt_registration_number = 'default', 
                    invoice = 'default', 
                    f_mark = 'default', 
                    f_shift = 'default', 
                    handmade_prepayment = 1000, 
                    merchandise_lines = [
                        vrt_ud.models.merchandise_line.MerchandiseLine(
                            goods_name = 'boxes', 
                            goods_unit_name = 'box', 
                            goods_unit_price = 500, 
                            goods_amount = 2, 
                            goods_value = 1000, 
                            vat_rate = 'VAT0000', 
                            barcode = 'default', 
                            fact_time = '2020-10-21T09:30+03:00', )
                        ], ), 
                fact_time = '2020-10-21T09:30+03:00'
            )
        else :
            return FactDemandPayment(
                performer_id = 'f_887',
                trip_id = 'default',
                order_id = 'default',
                demand_key = 'default',
                payment_details = vrt_ud.models.payment_details.PaymentDetails(
                    bill_number_in_shift = '1', 
                    bill_date_time = 'default', 
                    customer_email = 'customer@company.com', 
                    bill_amount_total = 1000, 
                    fd_number = 'default', 
                    fn_number = 'default', 
                    qr_code = 'default', 
                    payment_type = 'default', 
                    approval_code = 'default', 
                    kkt_registration_number = 'default', 
                    invoice = 'default', 
                    f_mark = 'default', 
                    f_shift = 'default', 
                    handmade_prepayment = 1000, 
                    merchandise_lines = [
                        vrt_ud.models.merchandise_line.MerchandiseLine(
                            goods_name = 'boxes', 
                            goods_unit_name = 'box', 
                            goods_unit_price = 500, 
                            goods_amount = 2, 
                            goods_value = 1000, 
                            vat_rate = 'VAT0000', 
                            barcode = 'default', 
                            fact_time = '2020-10-21T09:30+03:00', )
                        ], ),
        )

    def testFactDemandPayment(self):
        """Test FactDemandPayment"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from vrt_ud.api_client import ApiClient
from vrt_ud.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class PredictorApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def predictor_check(self, **kwargs):  # noqa: E501
        """Checking the time windows prediction feature.  # noqa: E501

        Monitoring the script that prepares data for time window prediction.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.predictor_check(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PredictorCheckResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.predictor_check_with_http_info(**kwargs)  # noqa: E501

    def predictor_check_with_http_info(self, **kwargs):  # noqa: E501
        """Checking the time windows prediction feature.  # noqa: E501

        Monitoring the script that prepares data for time window prediction.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.predictor_check_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PredictorCheckResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method predictor_check" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/predictor/check', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PredictorCheckResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def predictor_insert(self, predictor_insert_task, **kwargs):  # noqa: E501
        """Adding a new order.  # noqa: E501

        The script inserts and adds a single order if its fulfillment cost does not exceed the amount specified in the request. In this case the order is saved on the server.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.predictor_insert(predictor_insert_task, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PredictorInsertTask predictor_insert_task: Request to add an order. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.predictor_insert_with_http_info(predictor_insert_task, **kwargs)  # noqa: E501

    def predictor_insert_with_http_info(self, predictor_insert_task, **kwargs):  # noqa: E501
        """Adding a new order.  # noqa: E501

        The script inserts and adds a single order if its fulfillment cost does not exceed the amount specified in the request. In this case the order is saved on the server.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.predictor_insert_with_http_info(predictor_insert_task, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PredictorInsertTask predictor_insert_task: Request to add an order. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'predictor_insert_task'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method predictor_insert" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'predictor_insert_task' is set
        if self.api_client.client_side_validation and ('predictor_insert_task' not in local_var_params or  # noqa: E501
                                                        local_var_params['predictor_insert_task'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `predictor_insert_task` when calling `predictor_insert`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'predictor_insert_task' in local_var_params:
            body_params = local_var_params['predictor_insert_task']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/predictor/insert', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def predictor_predict(self, predictor_task, **kwargs):  # noqa: E501
        """Time window prediction.  # noqa: E501

        Getting a ranked list of windows for a new order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.predictor_predict(predictor_task, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PredictorTask predictor_task: New request for the time window prediction. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PredictorResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.predictor_predict_with_http_info(predictor_task, **kwargs)  # noqa: E501

    def predictor_predict_with_http_info(self, predictor_task, **kwargs):  # noqa: E501
        """Time window prediction.  # noqa: E501

        Getting a ranked list of windows for a new order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.predictor_predict_with_http_info(predictor_task, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PredictorTask predictor_task: New request for the time window prediction. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PredictorResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'predictor_task'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method predictor_predict" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'predictor_task' is set
        if self.api_client.client_side_validation and ('predictor_task' not in local_var_params or  # noqa: E501
                                                        local_var_params['predictor_task'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `predictor_task` when calling `predictor_predict`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'predictor_task' in local_var_params:
            body_params = local_var_params['predictor_task']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/predictor/predict', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PredictorResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import vrt_ud
from vrt_ud.api.configurator_api import ConfiguratorApi  # noqa: E501
from vrt_ud.rest import ApiException


class TestConfiguratorApi(unittest.TestCase):
    """ConfiguratorApi unit test stubs"""

    def setUp(self):
        self.api = vrt_ud.api.configurator_api.ConfiguratorApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_cfg(self):
        """Test case for create_cfg

        Configuration change.  # noqa: E501
        """
        pass

    def test_delete_cfg(self):
        """Test case for delete_cfg

        Configuration removal.  # noqa: E501
        """
        pass

    def test_read_cfg(self):
        """Test case for read_cfg

        Reading the configuration.  # noqa: E501
        """
        pass

    def test_read_cfg_names(self):
        """Test case for read_cfg_names

        Reading the configuration names.  # noqa: E501
        """
        pass

    def test_update_cfg(self):
        """Test case for update_cfg

        Configuration parameter change.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.demand import Demand  # noqa: E501
from vrt_ud.rest import ApiException

class TestDemand(unittest.TestCase):
    """Demand unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Demand
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.demand.Demand()  # noqa: E501
        if include_optional :
            return Demand(
                key = 'demand01.1', 
                demand_type = 'WORK', 
                target_cargos = ["cargo01"], 
                precedence_in_trip = 1, 
                precedence_in_order = 1, 
                possible_events = [
                    vrt_ud.models.possible_event.PossibleEvent(
                        location_key = 'location01', 
                        duration = 10, 
                        reward = 199.9, 
                        time_window = vrt_ud.models.time_window.TimeWindow(
                            from = '2020-10-21T09:30+03:00', 
                            to = '2020-10-21T19:45Z', ), )
                    ]
            )
        else :
            return Demand(
                key = 'demand01.1',
                demand_type = 'WORK',
                possible_events = [
                    vrt_ud.models.possible_event.PossibleEvent(
                        location_key = 'location01', 
                        duration = 10, 
                        reward = 199.9, 
                        time_window = vrt_ud.models.time_window.TimeWindow(
                            from = '2020-10-21T09:30+03:00', 
                            to = '2020-10-21T19:45Z', ), )
                    ],
        )

    def testDemand(self):
        """Test Demand"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class TripJob(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'job_type': 'str',
        'job_time': 'datetime'
    }

    attribute_map = {
        'job_type': 'job_type',
        'job_time': 'job_time'
    }

    def __init__(self, job_type=None, job_time=None, local_vars_configuration=None):  # noqa: E501
        """TripJob - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._job_type = None
        self._job_time = None
        self.discriminator = None

        self.job_type = job_type
        self.job_time = job_time

    @property
    def job_type(self):
        """Gets the job_type of this TripJob.  # noqa: E501

        Possible work types:   * `LOCATION_ARRIVAL` - Arrival to the location.   * `READY_TO_WORK` - The performer is ready to start.   * `START_WORK` - Start working at the location.   * `FINISH_WORK` - Finishing working at the location.   * `LOCATION_DEPARTURE` - Departure from the location.   * `CUSTOM` - Additional work.   # noqa: E501

        :return: The job_type of this TripJob.  # noqa: E501
        :rtype: str
        """
        return self._job_type

    @job_type.setter
    def job_type(self, job_type):
        """Sets the job_type of this TripJob.

        Possible work types:   * `LOCATION_ARRIVAL` - Arrival to the location.   * `READY_TO_WORK` - The performer is ready to start.   * `START_WORK` - Start working at the location.   * `FINISH_WORK` - Finishing working at the location.   * `LOCATION_DEPARTURE` - Departure from the location.   * `CUSTOM` - Additional work.   # noqa: E501

        :param job_type: The job_type of this TripJob.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and job_type is None:  # noqa: E501
            raise ValueError("Invalid value for `job_type`, must not be `None`")  # noqa: E501
        allowed_values = ["LOCATION_ARRIVAL", "READY_TO_WORK", "START_WORK", "FINISH_WORK", "LOCATION_DEPARTURE", "CUSTOM"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and job_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `job_type` ({0}), must be one of {1}"  # noqa: E501
                .format(job_type, allowed_values)
            )

        self._job_type = job_type

    @property
    def job_time(self):
        """Gets the job_time of this TripJob.  # noqa: E501

        Start time according to the [RFC 3339, section 5.6](https://tools.ietf.org/html/rfc3339#section-5.6).  # noqa: E501

        :return: The job_time of this TripJob.  # noqa: E501
        :rtype: datetime
        """
        return self._job_time

    @job_time.setter
    def job_time(self, job_time):
        """Sets the job_time of this TripJob.

        Start time according to the [RFC 3339, section 5.6](https://tools.ietf.org/html/rfc3339#section-5.6).  # noqa: E501

        :param job_time: The job_time of this TripJob.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and job_time is None:  # noqa: E501
            raise ValueError("Invalid value for `job_time`, must not be `None`")  # noqa: E501

        self._job_time = job_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TripJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TripJob):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class PaymentDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bill_number_in_shift': 'str',
        'bill_date_time': 'str',
        'customer_email': 'str',
        'bill_amount_total': 'float',
        'fd_number': 'str',
        'fn_number': 'str',
        'qr_code': 'str',
        'payment_type': 'str',
        'approval_code': 'str',
        'kkt_registration_number': 'str',
        'invoice': 'str',
        'f_mark': 'str',
        'f_shift': 'str',
        'handmade_prepayment': 'float',
        'merchandise_lines': 'list[MerchandiseLine]'
    }

    attribute_map = {
        'bill_number_in_shift': 'bill_number_in_shift',
        'bill_date_time': 'bill_date_time',
        'customer_email': 'customer_email',
        'bill_amount_total': 'bill_amount_total',
        'fd_number': 'fd_number',
        'fn_number': 'fn_number',
        'qr_code': 'qr_code',
        'payment_type': 'payment_type',
        'approval_code': 'approval_code',
        'kkt_registration_number': 'kkt_registration_number',
        'invoice': 'invoice',
        'f_mark': 'f_mark',
        'f_shift': 'f_shift',
        'handmade_prepayment': 'handmade_prepayment',
        'merchandise_lines': 'merchandise_lines'
    }

    def __init__(self, bill_number_in_shift=None, bill_date_time=None, customer_email=None, bill_amount_total=None, fd_number=None, fn_number=None, qr_code=None, payment_type=None, approval_code=None, kkt_registration_number=None, invoice=None, f_mark=None, f_shift=None, handmade_prepayment=None, merchandise_lines=None, local_vars_configuration=None):  # noqa: E501
        """PaymentDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bill_number_in_shift = None
        self._bill_date_time = None
        self._customer_email = None
        self._bill_amount_total = None
        self._fd_number = None
        self._fn_number = None
        self._qr_code = None
        self._payment_type = None
        self._approval_code = None
        self._kkt_registration_number = None
        self._invoice = None
        self._f_mark = None
        self._f_shift = None
        self._handmade_prepayment = None
        self._merchandise_lines = None
        self.discriminator = None

        if bill_number_in_shift is not None:
            self.bill_number_in_shift = bill_number_in_shift
        self.bill_date_time = bill_date_time
        if customer_email is not None:
            self.customer_email = customer_email
        if bill_amount_total is not None:
            self.bill_amount_total = bill_amount_total
        if fd_number is not None:
            self.fd_number = fd_number
        if fn_number is not None:
            self.fn_number = fn_number
        if qr_code is not None:
            self.qr_code = qr_code
        if payment_type is not None:
            self.payment_type = payment_type
        if approval_code is not None:
            self.approval_code = approval_code
        if kkt_registration_number is not None:
            self.kkt_registration_number = kkt_registration_number
        if invoice is not None:
            self.invoice = invoice
        if f_mark is not None:
            self.f_mark = f_mark
        if f_shift is not None:
            self.f_shift = f_shift
        if handmade_prepayment is not None:
            self.handmade_prepayment = handmade_prepayment
        self.merchandise_lines = merchandise_lines

    @property
    def bill_number_in_shift(self):
        """Gets the bill_number_in_shift of this PaymentDetails.  # noqa: E501

        Payment document number in the shift.  # noqa: E501

        :return: The bill_number_in_shift of this PaymentDetails.  # noqa: E501
        :rtype: str
        """
        return self._bill_number_in_shift

    @bill_number_in_shift.setter
    def bill_number_in_shift(self, bill_number_in_shift):
        """Sets the bill_number_in_shift of this PaymentDetails.

        Payment document number in the shift.  # noqa: E501

        :param bill_number_in_shift: The bill_number_in_shift of this PaymentDetails.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                bill_number_in_shift is not None and len(bill_number_in_shift) > 256):
            raise ValueError("Invalid value for `bill_number_in_shift`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                bill_number_in_shift is not None and len(bill_number_in_shift) < 1):
            raise ValueError("Invalid value for `bill_number_in_shift`, length must be greater than or equal to `1`")  # noqa: E501

        self._bill_number_in_shift = bill_number_in_shift

    @property
    def bill_date_time(self):
        """Gets the bill_date_time of this PaymentDetails.  # noqa: E501

        Time when the payment document was created.  # noqa: E501

        :return: The bill_date_time of this PaymentDetails.  # noqa: E501
        :rtype: str
        """
        return self._bill_date_time

    @bill_date_time.setter
    def bill_date_time(self, bill_date_time):
        """Sets the bill_date_time of this PaymentDetails.

        Time when the payment document was created.  # noqa: E501

        :param bill_date_time: The bill_date_time of this PaymentDetails.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and bill_date_time is None:  # noqa: E501
            raise ValueError("Invalid value for `bill_date_time`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                bill_date_time is not None and len(bill_date_time) > 256):
            raise ValueError("Invalid value for `bill_date_time`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                bill_date_time is not None and len(bill_date_time) < 1):
            raise ValueError("Invalid value for `bill_date_time`, length must be greater than or equal to `1`")  # noqa: E501

        self._bill_date_time = bill_date_time

    @property
    def customer_email(self):
        """Gets the customer_email of this PaymentDetails.  # noqa: E501

        Customer's email.  # noqa: E501

        :return: The customer_email of this PaymentDetails.  # noqa: E501
        :rtype: str
        """
        return self._customer_email

    @customer_email.setter
    def customer_email(self, customer_email):
        """Sets the customer_email of this PaymentDetails.

        Customer's email.  # noqa: E501

        :param customer_email: The customer_email of this PaymentDetails.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                customer_email is not None and len(customer_email) > 256):
            raise ValueError("Invalid value for `customer_email`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                customer_email is not None and len(customer_email) < 1):
            raise ValueError("Invalid value for `customer_email`, length must be greater than or equal to `1`")  # noqa: E501

        self._customer_email = customer_email

    @property
    def bill_amount_total(self):
        """Gets the bill_amount_total of this PaymentDetails.  # noqa: E501

        Total cost.  # noqa: E501

        :return: The bill_amount_total of this PaymentDetails.  # noqa: E501
        :rtype: float
        """
        return self._bill_amount_total

    @bill_amount_total.setter
    def bill_amount_total(self, bill_amount_total):
        """Sets the bill_amount_total of this PaymentDetails.

        Total cost.  # noqa: E501

        :param bill_amount_total: The bill_amount_total of this PaymentDetails.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                bill_amount_total is not None and bill_amount_total < 0):  # noqa: E501
            raise ValueError("Invalid value for `bill_amount_total`, must be a value greater than or equal to `0`")  # noqa: E501

        self._bill_amount_total = bill_amount_total

    @property
    def fd_number(self):
        """Gets the fd_number of this PaymentDetails.  # noqa: E501

        FD number.  # noqa: E501

        :return: The fd_number of this PaymentDetails.  # noqa: E501
        :rtype: str
        """
        return self._fd_number

    @fd_number.setter
    def fd_number(self, fd_number):
        """Sets the fd_number of this PaymentDetails.

        FD number.  # noqa: E501

        :param fd_number: The fd_number of this PaymentDetails.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                fd_number is not None and len(fd_number) > 256):
            raise ValueError("Invalid value for `fd_number`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                fd_number is not None and len(fd_number) < 1):
            raise ValueError("Invalid value for `fd_number`, length must be greater than or equal to `1`")  # noqa: E501

        self._fd_number = fd_number

    @property
    def fn_number(self):
        """Gets the fn_number of this PaymentDetails.  # noqa: E501

        FN number.  # noqa: E501

        :return: The fn_number of this PaymentDetails.  # noqa: E501
        :rtype: str
        """
        return self._fn_number

    @fn_number.setter
    def fn_number(self, fn_number):
        """Sets the fn_number of this PaymentDetails.

        FN number.  # noqa: E501

        :param fn_number: The fn_number of this PaymentDetails.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                fn_number is not None and len(fn_number) > 256):
            raise ValueError("Invalid value for `fn_number`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                fn_number is not None and len(fn_number) < 1):
            raise ValueError("Invalid value for `fn_number`, length must be greater than or equal to `1`")  # noqa: E501

        self._fn_number = fn_number

    @property
    def qr_code(self):
        """Gets the qr_code of this PaymentDetails.  # noqa: E501

        QR code.  # noqa: E501

        :return: The qr_code of this PaymentDetails.  # noqa: E501
        :rtype: str
        """
        return self._qr_code

    @qr_code.setter
    def qr_code(self, qr_code):
        """Sets the qr_code of this PaymentDetails.

        QR code.  # noqa: E501

        :param qr_code: The qr_code of this PaymentDetails.  # noqa: E501
        :type: str
        """

        self._qr_code = qr_code

    @property
    def payment_type(self):
        """Gets the payment_type of this PaymentDetails.  # noqa: E501

        Payment type.  # noqa: E501

        :return: The payment_type of this PaymentDetails.  # noqa: E501
        :rtype: str
        """
        return self._payment_type

    @payment_type.setter
    def payment_type(self, payment_type):
        """Sets the payment_type of this PaymentDetails.

        Payment type.  # noqa: E501

        :param payment_type: The payment_type of this PaymentDetails.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                payment_type is not None and len(payment_type) > 256):
            raise ValueError("Invalid value for `payment_type`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                payment_type is not None and len(payment_type) < 1):
            raise ValueError("Invalid value for `payment_type`, length must be greater than or equal to `1`")  # noqa: E501

        self._payment_type = payment_type

    @property
    def approval_code(self):
        """Gets the approval_code of this PaymentDetails.  # noqa: E501

        Approval code.  # noqa: E501

        :return: The approval_code of this PaymentDetails.  # noqa: E501
        :rtype: str
        """
        return self._approval_code

    @approval_code.setter
    def approval_code(self, approval_code):
        """Sets the approval_code of this PaymentDetails.

        Approval code.  # noqa: E501

        :param approval_code: The approval_code of this PaymentDetails.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                approval_code is not None and len(approval_code) > 256):
            raise ValueError("Invalid value for `approval_code`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                approval_code is not None and len(approval_code) < 1):
            raise ValueError("Invalid value for `approval_code`, length must be greater than or equal to `1`")  # noqa: E501

        self._approval_code = approval_code

    @property
    def kkt_registration_number(self):
        """Gets the kkt_registration_number of this PaymentDetails.  # noqa: E501

        Registration number.  # noqa: E501

        :return: The kkt_registration_number of this PaymentDetails.  # noqa: E501
        :rtype: str
        """
        return self._kkt_registration_number

    @kkt_registration_number.setter
    def kkt_registration_number(self, kkt_registration_number):
        """Sets the kkt_registration_number of this PaymentDetails.

        Registration number.  # noqa: E501

        :param kkt_registration_number: The kkt_registration_number of this PaymentDetails.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                kkt_registration_number is not None and len(kkt_registration_number) > 256):
            raise ValueError("Invalid value for `kkt_registration_number`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                kkt_registration_number is not None and len(kkt_registration_number) < 1):
            raise ValueError("Invalid value for `kkt_registration_number`, length must be greater than or equal to `1`")  # noqa: E501

        self._kkt_registration_number = kkt_registration_number

    @property
    def invoice(self):
        """Gets the invoice of this PaymentDetails.  # noqa: E501

        Invoice.  # noqa: E501

        :return: The invoice of this PaymentDetails.  # noqa: E501
        :rtype: str
        """
        return self._invoice

    @invoice.setter
    def invoice(self, invoice):
        """Sets the invoice of this PaymentDetails.

        Invoice.  # noqa: E501

        :param invoice: The invoice of this PaymentDetails.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                invoice is not None and len(invoice) > 1000):
            raise ValueError("Invalid value for `invoice`, length must be less than or equal to `1000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                invoice is not None and len(invoice) < 1):
            raise ValueError("Invalid value for `invoice`, length must be greater than or equal to `1`")  # noqa: E501

        self._invoice = invoice

    @property
    def f_mark(self):
        """Gets the f_mark of this PaymentDetails.  # noqa: E501

        f_mark.  # noqa: E501

        :return: The f_mark of this PaymentDetails.  # noqa: E501
        :rtype: str
        """
        return self._f_mark

    @f_mark.setter
    def f_mark(self, f_mark):
        """Sets the f_mark of this PaymentDetails.

        f_mark.  # noqa: E501

        :param f_mark: The f_mark of this PaymentDetails.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                f_mark is not None and len(f_mark) > 1000):
            raise ValueError("Invalid value for `f_mark`, length must be less than or equal to `1000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                f_mark is not None and len(f_mark) < 1):
            raise ValueError("Invalid value for `f_mark`, length must be greater than or equal to `1`")  # noqa: E501

        self._f_mark = f_mark

    @property
    def f_shift(self):
        """Gets the f_shift of this PaymentDetails.  # noqa: E501

        f_shift.  # noqa: E501

        :return: The f_shift of this PaymentDetails.  # noqa: E501
        :rtype: str
        """
        return self._f_shift

    @f_shift.setter
    def f_shift(self, f_shift):
        """Sets the f_shift of this PaymentDetails.

        f_shift.  # noqa: E501

        :param f_shift: The f_shift of this PaymentDetails.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                f_shift is not None and len(f_shift) > 1000):
            raise ValueError("Invalid value for `f_shift`, length must be less than or equal to `1000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                f_shift is not None and len(f_shift) < 1):
            raise ValueError("Invalid value for `f_shift`, length must be greater than or equal to `1`")  # noqa: E501

        self._f_shift = f_shift

    @property
    def handmade_prepayment(self):
        """Gets the handmade_prepayment of this PaymentDetails.  # noqa: E501

        Prepayment amount.  # noqa: E501

        :return: The handmade_prepayment of this PaymentDetails.  # noqa: E501
        :rtype: float
        """
        return self._handmade_prepayment

    @handmade_prepayment.setter
    def handmade_prepayment(self, handmade_prepayment):
        """Sets the handmade_prepayment of this PaymentDetails.

        Prepayment amount.  # noqa: E501

        :param handmade_prepayment: The handmade_prepayment of this PaymentDetails.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                handmade_prepayment is not None and handmade_prepayment < 0):  # noqa: E501
            raise ValueError("Invalid value for `handmade_prepayment`, must be a value greater than or equal to `0`")  # noqa: E501

        self._handmade_prepayment = handmade_prepayment

    @property
    def merchandise_lines(self):
        """Gets the merchandise_lines of this PaymentDetails.  # noqa: E501

        Product data.  # noqa: E501

        :return: The merchandise_lines of this PaymentDetails.  # noqa: E501
        :rtype: list[MerchandiseLine]
        """
        return self._merchandise_lines

    @merchandise_lines.setter
    def merchandise_lines(self, merchandise_lines):
        """Sets the merchandise_lines of this PaymentDetails.

        Product data.  # noqa: E501

        :param merchandise_lines: The merchandise_lines of this PaymentDetails.  # noqa: E501
        :type: list[MerchandiseLine]
        """
        if self.local_vars_configuration.client_side_validation and merchandise_lines is None:  # noqa: E501
            raise ValueError("Invalid value for `merchandise_lines`, must not be `None`")  # noqa: E501

        self._merchandise_lines = merchandise_lines

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PaymentDetails):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from vrt_ud.api.configurator_api import ConfiguratorApi
from vrt_ud.api.data_api import DataApi
from vrt_ud.api.monitor_api import MonitorApi
from vrt_ud.api.predictor_api import PredictorApi
from vrt_ud.api.reports_api import ReportsApi



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_ud.configuration import Configuration


class Order(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'key': 'str',
        'id': 'str',
        'state': 'str',
        'trip_id': 'str',
        'trip_short_key': 'str',
        'order_features': 'list[str]',
        'order_restrictions': 'list[str]',
        'performer_restrictions': 'list[str]',
        'cargos': 'list[Cargo]',
        'demands': 'list[Demand]'
    }

    attribute_map = {
        'key': 'key',
        'id': 'id',
        'state': 'state',
        'trip_id': 'trip_id',
        'trip_short_key': 'trip_short_key',
        'order_features': 'order_features',
        'order_restrictions': 'order_restrictions',
        'performer_restrictions': 'performer_restrictions',
        'cargos': 'cargos',
        'demands': 'demands'
    }

    def __init__(self, key=None, id=None, state=None, trip_id=None, trip_short_key=None, order_features=None, order_restrictions=None, performer_restrictions=None, cargos=None, demands=None, local_vars_configuration=None):  # noqa: E501
        """Order - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._key = None
        self._id = None
        self._state = None
        self._trip_id = None
        self._trip_short_key = None
        self._order_features = None
        self._order_restrictions = None
        self._performer_restrictions = None
        self._cargos = None
        self._demands = None
        self.discriminator = None

        self.key = key
        self.id = id
        self.state = state
        if trip_id is not None:
            self.trip_id = trip_id
        if trip_short_key is not None:
            self.trip_short_key = trip_short_key
        if order_features is not None:
            self.order_features = order_features
        if order_restrictions is not None:
            self.order_restrictions = order_restrictions
        if performer_restrictions is not None:
            self.performer_restrictions = performer_restrictions
        if cargos is not None:
            self.cargos = cargos
        self.demands = demands

    @property
    def key(self):
        """Gets the key of this Order.  # noqa: E501

        Unique order key.  # noqa: E501

        :return: The key of this Order.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this Order.

        Unique order key.  # noqa: E501

        :param key: The key of this Order.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and key is None:  # noqa: E501
            raise ValueError("Invalid value for `key`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                key is not None and len(key) > 1024):
            raise ValueError("Invalid value for `key`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                key is not None and len(key) < 1):
            raise ValueError("Invalid value for `key`, length must be greater than or equal to `1`")  # noqa: E501

        self._key = key

    @property
    def id(self):
        """Gets the id of this Order.  # noqa: E501

        Internal order ID.  # noqa: E501

        :return: The id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Order.

        Internal order ID.  # noqa: E501

        :param id: The id of this Order.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def state(self):
        """Gets the state of this Order.  # noqa: E501

        Order state.  # noqa: E501

        :return: The state of this Order.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Order.

        Order state.  # noqa: E501

        :param state: The state of this Order.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and state is None:  # noqa: E501
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                state is not None and len(state) > 256):
            raise ValueError("Invalid value for `state`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                state is not None and len(state) < 1):
            raise ValueError("Invalid value for `state`, length must be greater than or equal to `1`")  # noqa: E501

        self._state = state

    @property
    def trip_id(self):
        """Gets the trip_id of this Order.  # noqa: E501

        ID of the trip with an order.  # noqa: E501

        :return: The trip_id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._trip_id

    @trip_id.setter
    def trip_id(self, trip_id):
        """Sets the trip_id of this Order.

        ID of the trip with an order.  # noqa: E501

        :param trip_id: The trip_id of this Order.  # noqa: E501
        :type: str
        """

        self._trip_id = trip_id

    @property
    def trip_short_key(self):
        """Gets the trip_short_key of this Order.  # noqa: E501

        Short ID of the trip with an order.  # noqa: E501

        :return: The trip_short_key of this Order.  # noqa: E501
        :rtype: str
        """
        return self._trip_short_key

    @trip_short_key.setter
    def trip_short_key(self, trip_short_key):
        """Sets the trip_short_key of this Order.

        Short ID of the trip with an order.  # noqa: E501

        :param trip_short_key: The trip_short_key of this Order.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                trip_short_key is not None and len(trip_short_key) > 256):
            raise ValueError("Invalid value for `trip_short_key`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                trip_short_key is not None and len(trip_short_key) < 1):
            raise ValueError("Invalid value for `trip_short_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._trip_short_key = trip_short_key

    @property
    def order_features(self):
        """Gets the order_features of this Order.  # noqa: E501

        Order features list.  # noqa: E501

        :return: The order_features of this Order.  # noqa: E501
        :rtype: list[str]
        """
        return self._order_features

    @order_features.setter
    def order_features(self, order_features):
        """Sets the order_features of this Order.

        Order features list.  # noqa: E501

        :param order_features: The order_features of this Order.  # noqa: E501
        :type: list[str]
        """

        self._order_features = order_features

    @property
    def order_restrictions(self):
        """Gets the order_restrictions of this Order.  # noqa: E501

        List of requirements for an order to be delivered within the same trip.  # noqa: E501

        :return: The order_restrictions of this Order.  # noqa: E501
        :rtype: list[str]
        """
        return self._order_restrictions

    @order_restrictions.setter
    def order_restrictions(self, order_restrictions):
        """Sets the order_restrictions of this Order.

        List of requirements for an order to be delivered within the same trip.  # noqa: E501

        :param order_restrictions: The order_restrictions of this Order.  # noqa: E501
        :type: list[str]
        """

        self._order_restrictions = order_restrictions

    @property
    def performer_restrictions(self):
        """Gets the performer_restrictions of this Order.  # noqa: E501

        Performer's requirements list. It is used to check the compatibility of the performer to this work according to the performer's features list.  # noqa: E501

        :return: The performer_restrictions of this Order.  # noqa: E501
        :rtype: list[str]
        """
        return self._performer_restrictions

    @performer_restrictions.setter
    def performer_restrictions(self, performer_restrictions):
        """Sets the performer_restrictions of this Order.

        Performer's requirements list. It is used to check the compatibility of the performer to this work according to the performer's features list.  # noqa: E501

        :param performer_restrictions: The performer_restrictions of this Order.  # noqa: E501
        :type: list[str]
        """

        self._performer_restrictions = performer_restrictions

    @property
    def cargos(self):
        """Gets the cargos of this Order.  # noqa: E501

        Cargoes list (can have one cargo for DROP, a list for PICKUP, empty list for WORK)  # noqa: E501

        :return: The cargos of this Order.  # noqa: E501
        :rtype: list[Cargo]
        """
        return self._cargos

    @cargos.setter
    def cargos(self, cargos):
        """Sets the cargos of this Order.

        Cargoes list (can have one cargo for DROP, a list for PICKUP, empty list for WORK)  # noqa: E501

        :param cargos: The cargos of this Order.  # noqa: E501
        :type: list[Cargo]
        """

        self._cargos = cargos

    @property
    def demands(self):
        """Gets the demands of this Order.  # noqa: E501

        Demands list.  # noqa: E501

        :return: The demands of this Order.  # noqa: E501
        :rtype: list[Demand]
        """
        return self._demands

    @demands.setter
    def demands(self, demands):
        """Sets the demands of this Order.

        Demands list.  # noqa: E501

        :param demands: The demands of this Order.  # noqa: E501
        :type: list[Demand]
        """
        if self.local_vars_configuration.client_side_validation and demands is None:  # noqa: E501
            raise ValueError("Invalid value for `demands`, must not be `None`")  # noqa: E501

        self._demands = demands

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Order):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Order):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.inline_response504 import InlineResponse504  # noqa: E501
from vrt_ud.rest import ApiException

class TestInlineResponse504(unittest.TestCase):
    """InlineResponse504 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponse504
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.inline_response504.InlineResponse504()  # noqa: E501
        if include_optional :
            return InlineResponse504(
                tracedata = vrt_ud.models.trace_data.TraceData(
                    code = 'client_server_service_time_id', ), 
                message = 'Gateway Timeout', 
                code = 1504
            )
        else :
            return InlineResponse504(
                code = 1504,
        )

    def testInlineResponse504(self):
        """Test InlineResponse504"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.8.161005
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from vrt_ud.models.advanced_location import AdvancedLocation
from vrt_ud.models.assigned_shift import AssignedShift
from vrt_ud.models.capacity import Capacity
from vrt_ud.models.cargo import Cargo
from vrt_ud.models.cargo_placement import CargoPlacement
from vrt_ud.models.configuration import Configuration
from vrt_ud.models.data_load_multipart_task import DataLoadMultipartTask
from vrt_ud.models.data_load_task import DataLoadTask
from vrt_ud.models.delete_filter import DeleteFilter
from vrt_ud.models.demand import Demand
from vrt_ud.models.fact_demand_cancellation import FactDemandCancellation
from vrt_ud.models.fact_demand_done import FactDemandDone
from vrt_ud.models.fact_demand_payment import FactDemandPayment
from vrt_ud.models.fact_demand_resumed import FactDemandResumed
from vrt_ud.models.fact_event_window_changed import FactEventWindowChanged
from vrt_ud.models.fact_job_done import FactJobDone
from vrt_ud.models.fact_performer_message import FactPerformerMessage
from vrt_ud.models.fact_photo import FactPhoto
from vrt_ud.models.fact_trip_progress import FactTripProgress
from vrt_ud.models.fact_trip_status_notice import FactTripStatusNotice
from vrt_ud.models.fact_tripaction_comment_changed import FactTripactionCommentChanged
from vrt_ud.models.fact_work_started import FactWorkStarted
from vrt_ud.models.facts_filter import FactsFilter
from vrt_ud.models.facts_result import FactsResult
from vrt_ud.models.inline_response400 import InlineResponse400
from vrt_ud.models.inline_response401 import InlineResponse401
from vrt_ud.models.inline_response403 import InlineResponse403
from vrt_ud.models.inline_response404 import InlineResponse404
from vrt_ud.models.inline_response415 import InlineResponse415
from vrt_ud.models.inline_response429 import InlineResponse429
from vrt_ud.models.inline_response500 import InlineResponse500
from vrt_ud.models.inline_response501 import InlineResponse501
from vrt_ud.models.inline_response502 import InlineResponse502
from vrt_ud.models.inline_response503 import InlineResponse503
from vrt_ud.models.inline_response504 import InlineResponse504
from vrt_ud.models.inline_response_default import InlineResponseDefault
from vrt_ud.models.load_window import LoadWindow
from vrt_ud.models.location import Location
from vrt_ud.models.merchandise_line import MerchandiseLine
from vrt_ud.models.order import Order
from vrt_ud.models.order_cancellation import OrderCancellation
from vrt_ud.models.orders_filter import OrdersFilter
from vrt_ud.models.orders_result import OrdersResult
from vrt_ud.models.payment_details import PaymentDetails
from vrt_ud.models.performer_track import PerformerTrack
from vrt_ud.models.performers_filter import PerformersFilter
from vrt_ud.models.photos_filter import PhotosFilter
from vrt_ud.models.possible_event import PossibleEvent
from vrt_ud.models.predict_result_window import PredictResultWindow
from vrt_ud.models.predictor_check_result import PredictorCheckResult
from vrt_ud.models.predictor_insert_task import PredictorInsertTask
from vrt_ud.models.predictor_result import PredictorResult
from vrt_ud.models.predictor_task import PredictorTask
from vrt_ud.models.report_filter import ReportFilter
from vrt_ud.models.run_trips_task import RunTripsTask
from vrt_ud.models.time_window import TimeWindow
from vrt_ud.models.trace_data import TraceData
from vrt_ud.models.track_point import TrackPoint
from vrt_ud.models.tracks_result import TracksResult
from vrt_ud.models.trip import Trip
from vrt_ud.models.trip_action import TripAction
from vrt_ud.models.trip_job import TripJob
from vrt_ud.models.trips_filter import TripsFilter
from vrt_ud.models.trips_result import TripsResult
